===========
40.0 Dr Who
===========

The Avocado team is proud to present another release:
Avocado version 40.0, aka, "Dr Who", is now available!

Release documentation: `Avocado 40.0
<http://avocado-framework.readthedocs.io/en/40.0/>`_

The major changes introduced on this version are listed below.

* The introduction of a tool that generated a diff-like report of two
  jobs.  For more information on this feature, please check out its
  own documentation at :ref:`job-diff`.

* The :mod:`avocado.utils.process` library has been enhanced by adding
  the :meth:`avocado.utils.process.SubProcess.get_pid` method, and also by
  logging the command name, status and execution time when verbose
  mode is set.

* The introduction of a `rr <http://rr-project.org>`_ based wrapper.
  With such a wrapper, it's possible to transparently record the
  process state (when executed via the :mod:`avocado.utils.process`
  APIs), and deterministically replay them later.

* The coredump generation contrib scripts will check if the user
  running Avocado is privileged to actually generate those dumps.
  This means that it won't give errors in the UI about failures on
  pre/post scripts, but will record that in the appropriate job log.

* BUGFIX: The ``--remote-no-copy`` command line option, when added to the
  ``--remote-*`` options that actually trigger the remote execution of
  tests, will now skip the local test discovery altogether.

* BUGFIX: The use of the asset fetcher by multiple avocado executions
  could result in a race condition.  This is now fixed, backed by a
  file based utility lock library: :mod:`avocado.utils.filelock`.

* BUGFIX: The asset fetcher will now properly check the hash on
  ``file:`` based URLs.

* BUGFIX: A busy loop in the :mod:`avocado.utils.process` library that
  was reported by our users was promptly fixed.

* BUGFIX: Attempts to install Avocado on bare bones environments, such
  as virtualenvs, won't fail anymore due to dependencies required at
  ``setup.py`` execution time.  Of course Avocado still requires some
  external Python libraries, but these will only be required after
  installation.  This should let users to ``pip install avocado-framework``
  successfully.

For more information, please check out the complete
`Avocado changelog
<https://github.com/avocado-framework/avocado/compare/39.0...40.0>`_.

Release Meeting
===============

The Avocado release meetings are now open to the community via
Hangouts on Air.  The meetings are recorded and made available on the
`Avocado Test Framework YouTube channel
<https://www.youtube.com/channel/UC-RVZ_HFTbEztDM7wNY4NfA>`_.

For this release, you can watch the meeting on `this link
<https://www.youtube.com/watch?v=bWL8JHYN_ec>`_.

----

| Sprint theme: https://trello.com/c/P1Ps7T0F/782-sprint-theme-dr-who
